/* 
 
  Utilisation d’une photo-résistance 
*/
int port = A5;    
int valeur = 0;  
float vin = 0;
/**
 * Exemple de code pour lire plusieurs capteurs DS18B20 sur un mÃªme bus 1-Wire.
 */
 
/* DÃ©pendance pour le bus 1-Wire */
#include <OneWire.h>
 
 
/* Broche du bus 1-Wire */
const byte BROCHE_ONEWIRE = 7;

/* Code de retour de la fonction getTemperature() */
enum DS18B20_RCODES {
  READ_OK,
  NO_SENSOR_FOUND,
  INVALID_ADDRESS,
  INVALID_SENSOR
};


/* CrÃ©ation de l'objet OneWire pour manipuler le bus 1-Wire */
OneWire ds(BROCHE_ONEWIRE);
 
 
/**
 * Fonction de lecture de la tempÃ©rature via un capteur DS18B20.
 */
byte getTemperature(float *temperature, byte reset_search) {
  byte data[9], addr[8];
  // data[] : DonnÃ©es lues depuis le scratchpad
  // addr[] : Adresse du module 1-Wire dÃ©tectÃ©
  
  /* Reset le bus 1-Wire ci nÃ©cessaire (requis pour la lecture du premier capteur) */
  if (reset_search) {
    ds.reset_search();
  }
 
  /* Recherche le prochain capteur 1-Wire disponible */
  if (!ds.search(addr)) {
    // Pas de capteur
    return NO_SENSOR_FOUND;
  }
  
  /* VÃ©rifie que l'adresse a Ã©tÃ© correctement reÃ§ue */
  if (OneWire::crc8(addr, 7) != addr[7]) {
    // Adresse invalide
    return INVALID_ADDRESS;
  }
 
  /* VÃ©rifie qu'il s'agit bien d'un DS18B20 */
  if (addr[0] != 0x28) {
    // Mauvais type de capteur
    return INVALID_SENSOR;
  }
 
  /* Reset le bus 1-Wire et sÃ©lectionne le capteur */
  ds.reset();
  ds.select(addr);
  
  /* Lance une prise de mesure de tempÃ©rature et attend la fin de la mesure */
  ds.write(0x44, 1);
  delay(800);
  
  /* Reset le bus 1-Wire, sÃ©lectionne le capteur et envoie une demande de lecture du scratchpad */
  ds.reset();
  ds.select(addr);
  ds.write(0xBE);
 
 /* Lecture du scratchpad */
  for (byte i = 0; i < 9; i++) {
    data[i] = ds.read();
  }
   
  /* Calcul de la tempÃ©rature en degrÃ© Celsius */
  *temperature = ((data[1] << 8) | data[0]) * 0.0625; 
  
  // Pas d'erreur
  return READ_OK;
}
void setup() 
{
    Serial.begin(115200);}
void loop() 
{ 
  // Lit l’entrée analogique A0 
  valeur = analogRead(port);    
  // convertit l’entrée en volt 
  vin = (valeur * 5.0) / 1024.0; 
   Serial.println("luminosité= ");
  Serial.println(vin);  
  float temperature[3];
   
  /* Lit les tempÃ©ratures des trois capteurs */
  if (getTemperature(&temperature[0], true) != READ_OK) {
    Serial.println(F("Erreur de lecture du capteur 1"));
    return;
  }
  if (getTemperature(&temperature[1], false) != READ_OK) {
    Serial.println(F("Erreur de lecture du capteur 2"));
    return;
  }
  if (getTemperature(&temperature[2], false) != READ_OK) {
    Serial.println(F("Erreur de lecture du capteur 3"));
    return;
  }
   
  /* Affiche les tempÃ©ratures */
  Serial.print(F("Temperatures : "));
  Serial.print(temperature[0], 2);
  Serial.write(176); // CaractÃ¨re degrÃ©
  Serial.print(F("C, "));
  Serial.print(temperature[1], 2);
  Serial.write(176); // CaractÃ¨re degrÃ©
  Serial.print(F("C, "));
  Serial.print(temperature[2], 2);
  Serial.write(176); // CaractÃ¨re degrÃ©       
}
